use bevy::prelude::*;

pub struct SetupPlugin;

impl Plugin for SetupPlugin {
	fn build(&self, app: &mut AppBuilder) {
		app.add_startup_system(system.system());
	}
}

fn system(
	mut commands: Commands,
	asset_server: Res<AssetServer>,
	mut materials: ResMut<Assets<ColorMaterial>>,
) {
	// ui camera
	commands.spawn_bundle(UiCameraBundle::default());
	// root node
	commands
		.spawn_bundle(NodeBundle {
			style: Style {
				size: Size::new(Val::Percent(100.0), Val::Percent(100.0)),
				justify_content: JustifyContent::SpaceBetween,
				..Default::default()
			},
			material: materials.add(Color::NONE.into()),
			..Default::default()
		})
		.with_children(|parent| {
			parent
				.spawn_bundle(NodeBundle {
					style: Style {
						size: Size::new(Val::Px(200.0), Val::Percent(100.0)),
						border: Rect::all(Val::Px(2.0)),
						..Default::default()
					},
					material: materials.add(Color::rgb(0.65, 0.65, 0.65).into()),
					..Default::default()
				})
				.with_children(|parent| {
					parent.spawn_bundle(TextBundle {
						style: Style {
							align_self: AlignSelf::FlexEnd,
							..Default::default()
						},
						text: Text::with_section(
							"Ëxample text",
							TextStyle {
								font: asset_server.load("fonts/fantasque.ttf"),
								font_size: 30.0,
								..Default::default()
							},
							Default::default(),
						),
						..Default::default()
					});
				});
		});
}
